var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __values = (this && this.__values) || function(o) {
    var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
    if (m) return m.call(o);
    if (o && typeof o.length === "number") return {
        next: function () {
            if (o && i >= o.length) o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
    throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
};
import React from "react";
import { createDatabase, generateId, manyOf, oneOf } from "@testing-initializer/data";
import { render, screen } from "@testing-library/react";
import "@testing-library/jest-dom";
import { createRenderer } from "../create-renderer";
var db = createDatabase({
    user: {
        id: function () { return generateId("user-pk"); },
        name: function () { return "User ".concat(generateId("user-name")); },
    },
    toDo: {
        id: function () { return generateId("toDo-pk"); },
        name: function () { return "Todo ".concat(generateId("toDo-name")); },
    },
    project: {
        id: function () { return generateId("project-pk"); },
        date: function () { return new Date().toISOString(); },
        name: function () { return "Project ".concat(generateId("project-name")); },
        user: oneOf("user"),
        toDos: manyOf("toDo"),
    },
});
it("should allow to create renderer with relationships coming from props itself", function () {
    var e_1, _a;
    var TestComponent = function (_a) {
        var project = _a.project;
        return (React.createElement("div", null,
            React.createElement("p", null, project.user.name),
            React.createElement("p", null, project.name),
            React.createElement("div", null, project.toDos.map(function (_a) {
                var id = _a.id, name = _a.name;
                return (React.createElement("p", { key: id }, name));
            }))));
    };
    var renderTestComponent = createRenderer({
        component: TestComponent,
        props: {
            currentUser: db.user.create(),
            toDos: [db.toDo.create(), db.toDo.create(), db.toDo.create()],
            project: function (_a) {
                var currentUser = _a.currentUser, toDos = _a.toDos;
                return db.project.create({ toDos: toDos, user: currentUser });
            },
        },
        renderFunction: render,
    });
    var _b = renderTestComponent(), project = _b.project, currentUser = _b.currentUser, toDos = _b.toDos;
    expect(screen.getByText(currentUser.name)).toBeInTheDocument();
    expect(screen.getByText(project.name)).toBeInTheDocument();
    try {
        for (var toDos_1 = __values(toDos), toDos_1_1 = toDos_1.next(); !toDos_1_1.done; toDos_1_1 = toDos_1.next()) {
            var toDo = toDos_1_1.value;
            expect(screen.getByText(toDo.name)).toBeInTheDocument();
        }
    }
    catch (e_1_1) { e_1 = { error: e_1_1 }; }
    finally {
        try {
            if (toDos_1_1 && !toDos_1_1.done && (_a = toDos_1.return)) _a.call(toDos_1);
        }
        finally { if (e_1) throw e_1.error; }
    }
});
it("should allow to create renderer with relationships coming from data", function () {
    var e_2, _a;
    var TestComponent = function (_a) {
        var project = _a.project;
        return (React.createElement("div", null,
            React.createElement("p", null, project.user.name),
            React.createElement("p", null, project.name),
            React.createElement("div", null, project.toDos.map(function (_a) {
                var id = _a.id, name = _a.name;
                return (React.createElement("p", { key: id }, name));
            }))));
    };
    var renderTestComponent = createRenderer({
        component: TestComponent,
        data: {
            currentUser: db.user.create(),
            toDos: [db.toDo.create(), db.toDo.create(), db.toDo.create()],
        },
        props: function (_a) {
            var currentUser = _a.currentUser, toDos = _a.toDos;
            return ({
                project: db.project.create({ toDos: toDos, user: currentUser }),
            });
        },
        renderFunction: render,
    });
    var _b = renderTestComponent({
        currentUser: db.user.create({ name: "User override" }),
    }), project = _b.project, currentUser = _b.currentUser, toDos = _b.toDos;
    expect(screen.getByText(currentUser.name)).toBeInTheDocument();
    expect(screen.getByText(project.name)).toBeInTheDocument();
    try {
        for (var toDos_2 = __values(toDos), toDos_2_1 = toDos_2.next(); !toDos_2_1.done; toDos_2_1 = toDos_2.next()) {
            var toDo = toDos_2_1.value;
            expect(screen.getByText(toDo.name)).toBeInTheDocument();
        }
    }
    catch (e_2_1) { e_2 = { error: e_2_1 }; }
    finally {
        try {
            if (toDos_2_1 && !toDos_2_1.done && (_a = toDos_2.return)) _a.call(toDos_2);
        }
        finally { if (e_2) throw e_2.error; }
    }
});
it("should allow to create renderer with wrapper", function () {
    var TestComponent = function () {
        return (React.createElement("div", null,
            React.createElement("p", null, "hey")));
    };
    var renderTestComponent = createRenderer({
        component: TestComponent,
        renderFunction: render,
        wrapper: function (_a) {
            var children = _a.children;
            return (React.createElement("div", null,
                React.createElement("p", null, "I am inside the wrapper!"),
                children));
        },
    });
    renderTestComponent();
    expect(screen.getByText("I am inside the wrapper!")).toBeInTheDocument();
    expect(screen.getByText("hey")).toBeInTheDocument();
});
it("should allow to create renderer with custom render function", function () {
    var renderWithProviders = function (ui) {
        return __assign({}, render(ui, {
            wrapper: function (_a) {
                var children = _a.children;
                return (React.createElement("div", null,
                    React.createElement("p", null, "I'am inside a custom render function wrapper!"),
                    children));
            },
        }));
    };
    var TestComponent = function () {
        return (React.createElement("div", null,
            React.createElement("p", null, "hey")));
    };
    var renderTestComponent = createRenderer({
        component: TestComponent,
        renderFunction: renderWithProviders,
    });
    renderTestComponent();
    expect(screen.getByText("I'am inside a custom render function wrapper!")).toBeInTheDocument();
    expect(screen.getByText("hey")).toBeInTheDocument();
});
//# sourceMappingURL=create-renderer.js.map